diff --git a/pom.xml b/pom.xml
index fb902925b..74c09d833 100644
--- a/pom.xml
+++ b/pom.xml
@@ -651,6 +651,17 @@
1.2.9
+
+ org.slf4j
+ slf4j-api
+ 1.7.2
+
+
+ org.slf4j
+ slf4j-simple
+ 1.7.2
+
+
org.testng
testng
diff --git a/xwork-core/pom.xml b/xwork-core/pom.xml
index 8294d382e..88aa62987 100644
--- a/xwork-core/pom.xml
+++ b/xwork-core/pom.xml
@@ -268,6 +268,17 @@
test
+
+
+ org.slf4j
+ slf4j-api
+ true
+
+
+ org.slf4j
+ slf4j-simple
+ true
+
diff --git a/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/slf4j/Slf4jLogger.java b/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/slf4j/Slf4jLogger.java
new file mode 100644
index 000000000..d0f1237a8
--- /dev/null
+++ b/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/slf4j/Slf4jLogger.java
@@ -0,0 +1,108 @@
+/*
+ * Copyright 2002-2006,2009 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package com.opensymphony.xwork2.util.logging.slf4j;
+
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerUtils;
+
+/**
+ * Simple logger that delegates to slf4j logging
+ */
+public class Slf4jLogger implements Logger {
+
+ private org.slf4j.Logger log;
+
+ public Slf4jLogger(org.slf4j.Logger log) {
+ this.log = log;
+ }
+
+ public void error(String msg, String... args) {
+ log.error(LoggerUtils.format(msg, args));
+ }
+
+ public void error(String msg, Throwable ex, String... args) {
+ log.error(LoggerUtils.format(msg, args), ex);
+ }
+
+ public void info(String msg, String... args) {
+ log.info(LoggerUtils.format(msg, args));
+ }
+
+ public void info(String msg, Throwable ex, String... args) {
+ log.info(LoggerUtils.format(msg, args), ex);
+ }
+
+
+
+ public boolean isInfoEnabled() {
+ return log.isInfoEnabled();
+ }
+
+ public void warn(String msg, String... args) {
+ log.warn(LoggerUtils.format(msg, args));
+ }
+
+ public void warn(String msg, Throwable ex, String... args) {
+ log.warn(LoggerUtils.format(msg, args), ex);
+ }
+
+ public boolean isDebugEnabled() {
+ return log.isDebugEnabled();
+ }
+
+ public void debug(String msg, String... args) {
+ log.debug(LoggerUtils.format(msg, args));
+ }
+
+ public void debug(String msg, Throwable ex, String... args) {
+ log.debug(LoggerUtils.format(msg, args), ex);
+ }
+
+ public boolean isTraceEnabled() {
+ return log.isTraceEnabled();
+ }
+
+ public void trace(String msg, String... args) {
+ log.trace(LoggerUtils.format(msg, args));
+ }
+
+ public void trace(String msg, Throwable ex, String... args) {
+ log.trace(LoggerUtils.format(msg, args), ex);
+ }
+
+
+ public void fatal(String msg, String... args) {
+ log.error(LoggerUtils.format(msg, args));
+ }
+
+ public void fatal(String msg, Throwable ex, String... args) {
+ log.error(LoggerUtils.format(msg, args), ex);
+ }
+
+ public boolean isErrorEnabled() {
+ return log.isErrorEnabled();
+ }
+
+ /** Fatal is not support by Slf4j */
+ public boolean isFatalEnabled() {
+ return log.isErrorEnabled();
+ }
+
+ public boolean isWarnEnabled() {
+ return log.isWarnEnabled();
+ }
+
+}
diff --git a/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/slf4j/Slf4jLoggerFactory.java b/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/slf4j/Slf4jLoggerFactory.java
new file mode 100644
index 000000000..f50cfac50
--- /dev/null
+++ b/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/slf4j/Slf4jLoggerFactory.java
@@ -0,0 +1,36 @@
+/*
+ * Copyright 2002-2006,2009 The Apache Software Foundation.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package com.opensymphony.xwork2.util.logging.slf4j;
+
+import com.opensymphony.xwork2.util.logging.Logger;
+import com.opensymphony.xwork2.util.logging.LoggerFactory;
+
+/**
+ * Creates slf4j-logging-backed loggers
+ */
+public class Slf4jLoggerFactory extends LoggerFactory {
+
+ @Override
+ protected Logger getLoggerImpl(Class> cls) {
+ return new Slf4jLogger(org.slf4j.LoggerFactory.getLogger(cls));
+ }
+
+ @Override
+ protected Logger getLoggerImpl(String name) {
+ return new Slf4jLogger(org.slf4j.LoggerFactory.getLogger(name));
+ }
+
+}
diff --git a/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java b/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java
index 5dac28f53..edc9189bc 100644
--- a/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java
+++ b/xwork-core/src/main/java/com/opensymphony/xwork2/util/logging/LoggerFactory.java
@@ -16,6 +16,7 @@
package com.opensymphony.xwork2.util.logging;
import com.opensymphony.xwork2.util.logging.jdk.JdkLoggerFactory;
+import com.opensymphony.xwork2.util.logging.slf4j.Slf4jLoggerFactory;
import java.util.concurrent.locks.ReadWriteLock;
import java.util.concurrent.locks.ReentrantReadWriteLock;
@@ -59,11 +60,17 @@ public abstract class LoggerFactory {
try {
if (factory == null) {
try {
- Class.forName("org.apache.commons.logging.LogFactory");
- factory = new com.opensymphony.xwork2.util.logging.commons.CommonsLoggerFactory();
+ Class.forName("org.slf4j.LoggerFactory");
+ factory = new Slf4jLoggerFactory();
} catch (ClassNotFoundException ex) {
- // commons logging not found, falling back to jdk logging
- factory = new JdkLoggerFactory();
+ //slf4j not found try commons LogFactory
+ try {
+ Class.forName("org.apache.commons.logging.LogFactory");
+ factory = new com.opensymphony.xwork2.util.logging.commons.CommonsLoggerFactory();
+ } catch (ClassNotFoundException cnfex) {
+ // commons logging not found, falling back to jdk logging
+ factory = new JdkLoggerFactory();
+ }
}
}
return factory;